@@ -1,11 +1,11 @@
 package Net::DNS;
 
 #
-# $Id: DNS.pm 1207 2014-05-23 20:09:26Z willem $
+# $Id: DNS.pm 1221 2014-06-13 21:02:16Z willem $
 #
 use vars qw($VERSION $SVNVERSION);
-$VERSION    = '0.76';
-$SVNVERSION = (qw$LastChangedRevision: 1207 $)[1];
+$VERSION    = '0.77';
+$SVNVERSION = (qw$LastChangedRevision: 1221 $)[1];
 
 
 =head1 NAME
@@ -189,27 +189,26 @@ sub rr_del {
 #	Net::DNS::SEC 0.17 compatibility
 ########################################
 
-use constant OLDDNSSEC => eval {	## pre-load RRs
-	return 0 if $] < 5.006;
-	require Net::DNS::RR::DS;
-	return 0 unless $Net::DNS::RR::DS::VERSION < 1179;	# 0.17
-	require Net::DNS::RR::RRSIG;
-	require Net::DNS::RR::SIG;
+use constant OLDDNSSEC => Net::DNS::RR->COMPATIBLE;
 
-	foreach my $type (qw(DLV DNSKEY KEY NXT NSEC)) {
+if (OLDDNSSEC) {
+	require Net::DNS::RR::RRSIG;	## pre-load RRs
+	foreach my $type (qw(SIG DS DLV DNSKEY KEY NXT NSEC)) {
 		new Net::DNS::RR( type => $type );
 	}
-	return 1;
-} || 0;
 
-sub INIT {				## safe to ignore "Too late to run" warning
-					## only needed to satisfy DNSSEC t/00-load.t
+	eval {
+		no warnings 'void';	## suppress "Too late to run INIT block ..."
 
-	# attempt to pre-load RRs which have circular dependence problems
-	foreach my $type (qw(NSEC3 NSEC3PARAM)) {
-		last unless OLDDNSSEC;
-		new Net::DNS::RR( type => $type );
-	}
+		sub INIT {		## only needed to satisfy DNSSEC t/00-load.t
+			return unless OLDDNSSEC;
+
+			# attempt to pre-load RRs which have circular dependence problems
+			foreach my $type (qw(NSEC3 NSEC3PARAM)) {
+				new Net::DNS::RR( type => $type );
+			}
+		}
+	};
 }
 
 
@@ -234,7 +233,7 @@ sub typesbyval {
 	Net::DNS::Parameters::typebyval(shift);
 }
 
-unless (OLDDNSSEC) {
+if (OLDDNSSEC) {
 	use vars qw(%typesbyname %typesbyval);
 	%typesbyname = %Net::DNS::Parameters::typebyname;
 	%typesbyval  = %Net::DNS::Parameters::typebyval;
@@ -627,10 +626,10 @@ dynamic updates.
 
     use Net::DNS;
     my $res   = Net::DNS::Resolver->new;
-    my $query = $res->search("host.example.com");
+    my $reply = $res->search("host.example.com");
 
-    if ($query) {
-	foreach my $rr ($query->answer) {
+    if ($reply) {
+	foreach my $rr ($reply->answer) {
 	    next unless $rr->type eq "A";
 	    print $rr->address, "\n";
 	}
@@ -643,10 +642,10 @@ dynamic updates.
 
     use Net::DNS;
     my $res   = Net::DNS::Resolver->new;
-    my $query = $res->query("example.com", "NS");
+    my $reply = $res->query("example.com", "NS");
 
-    if ($query) {
-	foreach $rr (grep { $_->type eq 'NS' } $query->answer) {
+    if ($reply) {
+	foreach $rr (grep { $_->type eq 'NS' } $reply->answer) {
 	    print $rr->nsdname, "\n";
 	}
     }
@@ -675,10 +674,10 @@ dynamic updates.
 
     use Net::DNS;
     my $res   = Net::DNS::Resolver->new;
-    my $query = $res->query("example.com", "SOA");
+    my $reply = $res->query("example.com", "SOA");
 
-    if ($query) {
-	($query->answer)[0]->print;
+    if ($reply) {
+	($reply->answer)[0]->print;
     } else {
 	print "query failed: ", $res->errorstring, "\n";
     }
