@@ -1,10 +1,10 @@
 package Net::DNS::RR::TLSA;
 
 #
-# $Id: TLSA.pm 1140 2013-12-16 14:24:15Z willem $
+# $Id: TLSA.pm 1188 2014-04-03 18:54:34Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1140 $)[1];
+$VERSION = (qw$LastChangedRevision: 1188 $)[1];
 
 
 use strict;
@@ -16,6 +16,7 @@ Net::DNS::RR::TLSA - DNS TLSA resource record
 
 =cut
 
+
 use integer;
 
 
@@ -43,7 +44,7 @@ sub format_rdata {			## format rdata portion of RR string.
 	my $self = shift;
 
 	return '' unless defined $self->{certbin};
-	my @params = map $self->$_, qw(usage selector matchingtype);
+	my @params = ( $self->usage, $self->selector, $self->matchingtype );
 	( my $certificate = $self->cert ) =~ s/(\S{64})/$1\n/g;
 	chomp $certificate;
 	return join ' ', @params, $certificate if length $certificate < 40;
@@ -54,7 +55,9 @@ sub format_rdata {			## format rdata portion of RR string.
 sub parse_rdata {			## populate RR from rdata in argument list
 	my $self = shift;
 
-	$self->$_(shift) for qw(usage selector matchingtype);
+	$self->usage(shift);
+	$self->selector(shift);
+	$self->matchingtype(shift);
 	$self->cert(@_);
 }
 
@@ -66,6 +69,7 @@ sub usage {
 	return $self->{usage} || 0;
 }
 
+
 sub selector {
 	my $self = shift;
 
@@ -73,6 +77,7 @@ sub selector {
 	return $self->{selector} || 0;
 }
 
+
 sub matchingtype {
 	my $self = shift;
 
@@ -80,6 +85,7 @@ sub matchingtype {
 	return $self->{matchingtype} || 0;
 }
 
+
 sub cert {
 	my $self = shift;
 
@@ -87,6 +93,7 @@ sub cert {
 	unpack "H*", $self->certbin() if defined wantarray;
 }
 
+
 sub certbin {
 	my $self = shift;
 
@@ -94,6 +101,7 @@ sub certbin {
 	$self->{certbin} || "";
 }
 
+
 sub certificate { &cert; }
 
 1;
