@@ -1,10 +1,10 @@
 package Net::DNS::Resolver;
 
 #
-# $Id: Resolver.pm 1185 2014-04-03 09:21:21Z willem $
+# $Id: Resolver.pm 1218 2014-06-11 08:26:33Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1185 $)[1];
+$VERSION = (qw$LastChangedRevision: 1218 $)[1];
 
 =head1 NAME
 
@@ -37,8 +37,6 @@ BEGIN {
 	}
 }
 
-__PACKAGE__->init();
-
 
 1;
 
@@ -141,11 +139,11 @@ arguments to new() are supported:
 
 =item nameservers
 
-An array reference of nameservers to query.
+A reference to an array of nameservers to query.
 
 =item searchlist
 
-An array reference of domains.
+A reference to an array of domains to search for unqualified names.
 
 =item recurse
 
@@ -272,28 +270,55 @@ was an error.
     @zone = $res->axfr('example.com');
     @zone = $res->axfr('example.com', 'HS');
 
-Performs a zone transfer from the first nameserver listed in C<nameservers>.
-If the zone is omitted, it defaults to the first zone listed in the resolver
-search list.  If the class is omitted, it defaults to IN.
+    $iterator = $res->axfr;
+    $iterator = $res->axfr('example.com');
+    $iterator = $res->axfr('example.com', 'HS');
 
-Returns a list of C<Net::DNS::RR> objects, or empty list if the zone
-transfer failed.
+    $rr = $iterator->();
 
+Performs a zone transfer using the resolver nameservers list,
+attempted in the order listed.
+
+If the zone is omitted, it defaults to the first zone listed
+in the resolver search list.
+
+If the class is omitted, it defaults to IN.
+
+
+When called in list context, axfr() returns a list of L<Net::DNS::RR>
+objects or an empty list if the zone transfer failed.
 The redundant SOA record that terminates the zone transfer is not
 returned to the caller.
 
-Here's an example that uses a timeout and TSIG verification:
+Here is an example that uses a timeout and TSIG verification:
 
     $res->tcp_timeout( 10 );
     $res->tsig( 'Khmac-sha1.example.+161+24053.private' );
     my @zone = $res->axfr( 'example.com' );
 
-    if (@zone) {
-        foreach my $rr (@zone) {
-            $rr->print;
-        }
-    } else {
-        print 'Zone transfer failed: ', $res->errorstring, "\n";
+    die 'Zone transfer failed: ', $res->errorstring unless @zone;
+
+    foreach my $rr (@zone) {
+        $rr->print;
+    }
+
+
+When called in scalar context, axfr() returns an iterator object.
+Each invocation of the iterator returns a single L<Net::DNS::RR>
+or undef when the zone is exhausted.
+The redundant SOA record that terminates the zone transfer is not
+returned to the caller.
+
+Here is the example above, implemented using an iterator:
+
+    $res->tcp_timeout( 10 );
+    $res->tsig( 'Khmac-sha1.example.+161+24053.private' );
+    my $iterator = $res->axfr( 'example.com' );
+
+    die 'Zone transfer failed: ', $res->errorstring unless $iterator;
+
+    while ( my $rr = $iterator->() ) {
+        $rr->print;
     }
 
 
